@@ -18,7 +18,7 @@ import hildon
 import osso
 import sys
 
-version = "0.4.1"
+version = "0.4.2"
 settings_file_name = ".eggtimer"
 app_name = "eggtimer"
 
@@ -56,7 +56,9 @@ class eggtimerclass(hildon.Program):
 		self.window.connect("window-state-event", self.on_window_state_change) 
  		self.window_in_fullscreen = False #The window isn't in full screen mode initially.
 		
-		table = gtk.Table(rows=4, columns=5)
+		table = gtk.Table(rows=4, columns=6)
+		#table.set_row_spacings(5)
+		table.set_col_spacings(5)
 		
 		vbox=gtk.VBox(homogeneous=False, spacing=3)
 		
@@ -130,8 +132,22 @@ class eggtimerclass(hildon.Program):
 		table.attach(self.hourscale, left_attach=1, right_attach=2, top_attach=1, bottom_attach=3, xoptions=gtk.FILL, yoptions=gtk.FILL, xpadding=0, ypadding=10)
 		
 		self.labelTime = gtk.Label()
-		table.attach(self.labelTime, left_attach=4, right_attach=5, top_attach=1, bottom_attach=3, xoptions=gtk.EXPAND, yoptions=gtk.EXPAND, xpadding=0, ypadding=0)
+		table.attach(self.labelTime, left_attach=4, right_attach=6, top_attach=1, bottom_attach=3, xoptions=gtk.EXPAND, yoptions=gtk.EXPAND, xpadding=0, ypadding=0)
 		self.labelTime.set_markup('<span size="xx-large" weight="bold">00:00:00</span>')
+		
+		self.autorepeatbutton=gtk.ToggleButton("autorepeat")
+		self.autorepeatbutton.set_name("autorepeat")
+		self.autorepeatbutton.connect("clicked",self.on_button_clicked)
+		table.attach(self.autorepeatbutton,left_attach=4, right_attach=5, top_attach=3, bottom_attach=4, xoptions=gtk.FILL, yoptions=gtk.FILL, xpadding=0, ypadding=0)
+		
+		self.repeatlastbutton=gtk.Button("previous period")
+		self.repeatlastbutton.set_name("repeatlast")
+		self.repeatlastbutton.connect("clicked",self.on_button_clicked)
+		table.attach(self.repeatlastbutton,left_attach=5, right_attach=6, top_attach=3, bottom_attach=4, xoptions=gtk.FILL, yoptions=gtk.FILL, xpadding=0, ypadding=0)
+		
+		self.lastPeriod=0
+		self.setNewPeriod=True
+		
 		self.timer_id = None
 
 		#print "4: ",time.clock()
@@ -255,7 +271,6 @@ class eggtimerclass(hildon.Program):
 		except:
 			print 'rpc_run exception'
 		
-		
 		self.window.present()
 
         	btns = ( gtk.STOCK_CLOSE, gtk.RESPONSE_CLOSE )
@@ -282,10 +297,7 @@ class eggtimerclass(hildon.Program):
 		except:
 			print 'rpc_run exception'
 		
-	
-		#self.player.set_state(gst.STATE_NULL)
-		
-		#self.osso_c.system_note_dialog("Time is over.", type = 'notice')
+
 
 	def show_about(self, widget):
         	self.aboutdialog = gtk.AboutDialog()
@@ -329,7 +341,7 @@ class eggtimerclass(hildon.Program):
         		self.preferences['italic'] = fontDialog.get_property("italic")
 			
 		self.savePreferences()
-		print self.preferences
+		#print self.preferences
 		self.loadPreferences()
 
 		#if fontDialog.get_property("underline-set"):
@@ -353,6 +365,7 @@ class eggtimerclass(hildon.Program):
 			self.savePreferences()
         	fileChooser.destroy()
  
+ 
  	def on_beenden1_activate(self,widget):
 		self.destroy(self.window)
  
@@ -406,6 +419,13 @@ class eggtimerclass(hildon.Program):
 			if self.preferences['italic']:
 				self.style=self.style+' style="italic" '
 			
+		if self.preferences.has_key("lastPeriod"):
+			self.lastPeriod=int(self.preferences["lastPeriod"])
+			
+		if self.preferences.has_key("autoRepeatOn"):
+			if self.preferences["autoRepeatOn"]!="":
+				self.autorepeatbutton.set_active(True)
+
 		print "Fontattributes (PangoML):"+self.style
 
 		
@@ -423,6 +443,17 @@ class eggtimerclass(hildon.Program):
 			self.minscale.set_value(int(self.minscale.get_value())+time-60)
 			self.hourscale.set_value(int(self.hourscale.get_value()+1))
 		
+	def set_time(self, time):
+		hours=int(time//3600)
+		time=time-hours*3600
+		minutes=int(time//60)
+		secs=time-minutes*60
+		
+		print "set time:",hours,minutes,secs
+		
+		self.secscale.set_value(int(secs))
+		self.minscale.set_value(int(minutes))
+		self.hourscale.set_value(int(hours))
 			
 	def on_button_clicked(self,button):
 		if (button.get_name()=="plusbutton"):
@@ -442,6 +473,21 @@ class eggtimerclass(hildon.Program):
 			self.secscale.set_value(0)
 			self.minscale.set_value(0)
 			self.hourscale.set_value(0)
+		if (button.get_name()=="autorepeat"):	
+			if self.autorepeatbutton.get_active()==True:
+				self.preferences["autoRepeatOn"]="1"
+			else:
+				self.preferences["autoRepeatOn"]=""
+			
+			self.savePreferences()	
+		if (button.get_name()=="repeatlast"):	
+			if self.lastPeriod>0:
+				self.set_time(self.lastPeriod)
+			else:
+				mbox =  gtk.MessageDialog(None,gtk.DIALOG_MODAL,gtk.MESSAGE_INFO,gtk.BUTTONS_OK,"No last period.") 
+ 				response = mbox.run() 
+ 				mbox.hide() 
+ 				mbox.destroy() 
 		
 	def secelapsed(self):
 		def toStr(timestr):
@@ -459,9 +505,19 @@ class eggtimerclass(hildon.Program):
 			mvalue=int(self.minscale.get_value())
 			hvalue=int(self.hourscale.get_value())
 			
-
+			timetogo=svalue+60*mvalue+3600*hvalue
+			if self.lastPeriod<timetogo:
+				self.lastPeriod=timetogo
+				self.preferences["lastPeriod"]=timetogo
+				self.savePreferences()
+			if (self.setNewPeriod==True)and(timetogo>0):
+				self.lastPeriod=timetogo
+				self.setNewPeriod=False
+				
+			
 			self.labelTime.set_markup('<span '+self.style+'>'+toStr(hvalue)+":"+toStr(mvalue)+":"+toStr(svalue)+"</span>")
 			if ((svalue==0)and(mvalue==0)and(hvalue==0)): return True
+			
 			svalue-=1
 			if (svalue<0):
 				svalue=0
@@ -474,12 +530,20 @@ class eggtimerclass(hildon.Program):
 					if (hvalue<1):
 						hvalue=0
 						
-			if ((svalue==0)and(mvalue==0)and(hvalue==0)): self.timefinished()
-						
-			
+			self.labelTime.set_markup('<span '+self.style+'>'+toStr(hvalue)+":"+toStr(mvalue)+":"+toStr(svalue)+"</span>")
 			self.hourscale.set_value(hvalue)
 			self.minscale.set_value(mvalue)	
 			self.secscale.set_value(svalue)
+			
+			if ((svalue==0)and(mvalue==0)and(hvalue==0)): 
+				if (self.lastPeriod>0)and(self.autorepeatbutton.get_active()==True):
+					#print self.lastPeriod
+					self.set_time(self.lastPeriod)
+				else:
+					self.setNewPeriod=True
+				self.timefinished()
+			
+				
 		return True # run again in one second
 			
 
